@@ -13,11 +13,9 @@ void Remailer::setLog()
     if (!d_arg.option(&level, 'L'))
         level = configField("logLevel");
 
-    if (level.empty())
-        level = LOGDEFAULT;
-
     d_log.open(name);
     chmod(name.c_str(), S_IRUSR | S_IWUSR);
 
-    d_log.setLevel(stoul(level));
+    d_log.setLevel(level.empty() ? LOGDEFAULT : 
+                                    strToUnsigned(level, "logLevel"));
 }
